markuptools.MarkupInventory
===========================

.. inheritance-diagram:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory
   :private-bases:

.. autoclass:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.storage_format

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.name

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

Methods
-------

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.append

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.count

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.extend

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.index

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.insert

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.pop

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.remove

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.reverse

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.sort

    Inherited from :py:class:`__builtin__.list`

Special Methods
---------------

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__add__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__contains__

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__delitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__delslice__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__eq__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__ge__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__getitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__getslice__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__gt__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__iadd__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__imul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__iter__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__le__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__len__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__lt__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__mul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__ne__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__repr__

    Inherited from :py:class:`datastructuretools.ObjectInventory <abjad.tools.datastructuretools.ObjectInventory.ObjectInventory.ObjectInventory>`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__reversed__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__rmul__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__setitem__

    Inherited from :py:class:`__builtin__.list`

.. automethod:: abjad.tools.markuptools.MarkupInventory.MarkupInventory.MarkupInventory.__setslice__

    Inherited from :py:class:`__builtin__.list`
